function [] = infer_inject()
    % Load Data
    clear
    load human_to_reduced_data/data.mat areas counts hascenter hasfans...
        hasclimatefans hasembed haslakes ids;
    
    % "young" has max at 3.54 (n/h boundary), instead of 4.5 as max age
    % Max age from drawing from prior in inject case is 4. otherwise all
    % super old and the plots are not interesting.
    % p = 0.5 for all cases.
    % 10xA has areas = 10*areas to simulate getting more data
    %areas = 10*areas;
    [counts,hasfans,sampletimes] = trunc_prior_sample(areas,1.5,3.54,0.5);
    
    % Set Constants
    max_time = 4;
    num_units = length(areas);
    t = (0:0.05:max_time);
    p = (0:0.01:1); 
    exp_likelihood = zeros(length(p), length(t));
    [t_, p_] = meshgrid(t,p);
    
    for i = 1:length(p)
        for j = 1:length(t)
            log_likelihood_sum = 0;
            for k = 1:num_units
                [posterior, tc] = age_posterior(counts(k),areas(k),4.5);
                log_likelihood_sum = log_likelihood_sum +...
                    log10(sum(posterior.*step_likely(t(j),p(i),tc,hasfans(k))));

            end
            exp_likelihood(i,j) = log_likelihood_sum;
        end
        disp(i)
    end

    exp_likelihood(exp_likelihood == 0) = NaN;
    save stepdata_inject_15Ga_354trunc t_ p_ exp_likelihood sampletimes counts areas hasfans
end

function [samples,fans,sampletimes] = trunc_prior_sample(A,fan_time, max_time,p)
    % Set some constants
    N1_ref = 5.84e-4;
    N4_ref = 4.25e-5;
    
    % Define the prior 
    t = (0:0.01:max_time)';
    tc = 0.5*(t(1:end-1) + t(2:end));
    dens_t = (N4_ref/N1_ref)*(N1_ref*t + (3.79e-14)*(exp(6.93*t)-1));
    prior = diff(dens_t);
    prior = prior/sum(prior);
    
    % Sample from prior for each yellow - truncate for hasfans == 1
    randos = rand(length(A), 2);
    samples = zeros(length(A), 1);
    sampletimes = zeros(length(A), 1);
    fans = zeros(length(A),1);
    for i = 1:length(A)
        cdf = cumsum(prior);
        temptime = min(tc(cdf >= randos(i,1)));
        sampletimes(i) = temptime;
        tempdens = (N4_ref/N1_ref)*(N1_ref*temptime + (3.79e-14)*(exp(6.93*temptime)-1));
        samples(i) = poissrnd(A(i)*tempdens);
        if temptime >= fan_time
            if randos(i,2) <= p
               fans(i) = 1; 
            end
        end
    end
end

function likelihood = step_likely(t_spike, p_max, x,hasfan)
    likelihood = 0.001 + (p_max-0.001)*(x >= t_spike);
    if hasfan == 0
       likelihood = 1-likelihood; 
    end
end

function [posterior, tc] = age_posterior(N,A,max_time)
    % Set some constants
    N1_ref = 5.84e-4;
    N4_ref = 4.25e-5;
    
    % Define the prior and posterior functions
    t = (0:0.01:max_time)';
    tc = 0.5*(t(1:end-1) + t(2:end));
    dens_t = (N4_ref/N1_ref)*(N1_ref*t + (3.79e-14)*(exp(6.93*t)-1));
    prior = diff(dens_t);
    likelihood = poisspdf(N,0.5*(dens_t(1:end-1) + dens_t(2:end))*A);
    
    % Define and renormalize the posterior
    posterior = prior.*likelihood;
    posterior = posterior./sum(posterior);    
end