clear all
load human_to_reduced_data/data_spatial_2.mat areas  hasembed hasclimatefans counts hasfans


load slopedata_3_spatial_2

slope_like = 10.^exp_likelihood;

load stepdata_spatial_2

step_like = 10.^exp_likelihood;
step_like(isnan(step_like)) = 0;
dt = 0.01;
dt2 = 0.05;
dt3 = 0.1;

form_times = 0:0.01:4.5;
posts = zeros(length(counts), length(form_times)-1);
posts2 = zeros(length(counts), length(form_times)-1);
likelihoods = zeros(length(counts), length(form_times)-1);

for i = 1:length(counts)
   [posterior, tc] = age_posterior(counts(i),areas(i),max(form_times));
   [~,likelihood,~] = age_prior(counts(i),areas(i),max(form_times));
   likelihoods(i,:) = cumsum(likelihood)/sum(likelihood);
   posts(i,:) = 1 - cumsum(posterior');
   posts2(i,:) = posterior';
end

fan_posts = posts(hasfans == 1,:);
fan_posts2 = posts2(hasfans == 1, :);
non_fan_posts = posts2(hasfans == 0, :);

fan_likelihoods = likelihoods(hasfans == 1,:);
non_fan_likelihoods = likelihoods(hasfans == 0,:);

embed_posts = posts(hasfans == 1 & (hasembed ==1 | hasclimatefans == 1), :);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fig1 = figure('color',[1 1 1]);
sub_n0 = subplot(1,2,1);
[prior1, like1, tc1] = age_prior(counts(1),areas(1),4.5);
prior1 = prior1/sum(prior1);
like1 = like1/sum(like1);
post1 = prior1.*like1;
post1 = post1/sum(post1);
plot(tc1, prior1/dt,'linewidth',2);
hold on
plot(tc1,like1/dt,'linewidth',2);
plot(tc1,post1/dt,'k','linewidth',2);
axis([0 4.5 0 0.035/dt]);
xlabel({'Impact Unit Age, t (Ga)'});
ylabel({'Probability Density'});
grid on
legend('Prior, P(t)','Normalized Likelihood, P(k|t)','Posterior, P(t|k)','location','northwest');

sub_n1 = subplot(1,2,2);
[prior2, like2, tc2] = age_prior(counts(3),areas(3),4.5);
prior2 = prior2/sum(prior2);
like2 = like2/sum(like2);
post2 = prior2.*like2;
post2 = post2/sum(post2);
plot(tc2, prior2/dt,'linewidth',2);
hold on
plot(tc2,like2/dt,'linewidth',2);
plot(tc2,post2/dt,'k','linewidth',2);
axis([0 4.5 0 0.07/dt]);
xlabel({'Impact Unit Age, t (Ga)'});
ylabel({'Probability Density'});
grid on

legend('Prior, P(t)','Normalized Likelihood, P(k|t)','Posterior, P(t|k)','location','northwest');

fig1.PaperUnits = 'centimeters';
fig1.PaperPosition = [0 0 19.5 9.5];
print(fig1,'FIG1_spatial_2','-dtiffn','-r500');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fig2 = figure('color',[1 1 1]);
semilogy(form_times(1:end-1),prod(fan_posts,1),'linewidth',2,'Color',[0, 0.4470, 0.7410]);
hold on
semilogy(form_times(1:end-1),prod(embed_posts,1),'linewidth',2,'linestyle','--','Color',[0.8500, 0.3250, 0.0980]);
plot([0 4],[0.05 0.05],'color','k','linestyle','--','linewidth',1);
plot([0.9 0.9],[0.0001 1], 'color',[0, 0.4470, 0.7410],'linestyle','--','linewidth',1);
plot([2.5 2.5],[0.0001 1], 'color',[0.8500, 0.3250, 0.0980],'linestyle','--','linewidth',1);
text(0.05,0.018,{'At least one', 'younger', 'than 0.9 Ga'},'Color',[0, 0.4470, 0.7410],'fontsize',8);
text(1.65,0.018,{'At least one', 'younger', 'than 2.5 Ga'},'Color',[0.8500, 0.3250, 0.0980],'fontsize',8);
annotation('arrow',[0.34 0.24],[0.5 0.5],'Color',[0, 0.4470, 0.7410]);
annotation('arrow',[0.63 0.53],[0.5 0.5],'Color',[0.8500, 0.3250, 0.0980]);
axis([0 4 0.0001 1]);
legend('All Fan-Bearing','Localized Impact Trigger Excluded','location','southwest');
set(gca,'fontsize',10);
xlabel('Time, t_{ref} (Gyr)');
ylabel({'CDF of Youngest Fan Age','P(t_{min} \geq t_{ref} | t_{ref})'});
grid minor
fig2.PaperUnits = 'centimeters';
fig2.PaperPosition = [0 0 11 9.5];
print(fig2,'FIG2_spatial_2','-dtiffn','-r500');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fig3 = figure('color',[1 1 1]);
set(gca,'fontsize',10);
sub1 = subplot(1,2,1);
imagesc('XData',[0 4],'YData',[0 1],'CData',step_like) %CHANGED FOR LF2
hold on
step_sorted = sort(step_like(:));
step_cdf = 1 - cumsum(step_sorted)/sum(step_sorted);
step_val1 = min(step_sorted(step_cdf <= .997));
step_val2 = min(step_sorted(step_cdf <= .95));
step_val3 = min(step_sorted(step_cdf <= .68));
contour(t_,p_,step_like,[step_val1 step_val2 step_val3],'color','r','linewidth',1,'linestyle','-')

axis([0 4 0 1]); 
c2 = colorbar;
xlabel({'Fan Formation Time','\tau_{form} (Ga)'});
ylabel({'Max Fan Formation Prob.','p_{max}'});
set(gca,'tickdir','out');
% plot([1.5 1.5],[0 1],'color','r','linewidth',1,'linestyle','--');
% plot([0 4],[0.5 0.5],'color','r','linewidth',1,'linestyle','--');

sub2 = subplot(1,2,2);
step_marg_pdf = sum(step_like,1)/sum(step_like,'all');
step_marg_cdf = cumsum(step_marg_pdf);
step_marg_p5 = min(t_(1,step_marg_cdf >= 0.95));
plot(t_(1,:),step_marg_pdf/dt2,'linewidth',2)
hold on
patch([step_marg_p5 t_(1,t_(1,:) >= step_marg_p5)],...
    [0 step_marg_pdf(t_(1,:) >= step_marg_p5)]/dt2, [1 0 0],...
    'FaceAlpha',.3,'EdgeAlpha',0);
legend('PDF','p < 0.05','location','southwest');
grid minor
xlabel({'Fan Formation Time','\tau_{form} (Ga)'});
ylabel('Marginalized PDF');
disp(sum(step_marg_pdf(t_(1,:) >= 3)));
set(gca,'tickdir','out');

fig3.PaperUnits = 'centimeters';
fig3.PaperPosition = [0 0 19.5 9.5];
print(fig3,'FIG3_spatial_2','-dtiffn','-r500');



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fig4 = figure('color',[1 1 1]);
maximum = max(slope_like,[],'all');
[x,y,z] = find(slope_like == maximum);
set(gca,'fontsize',10);

sub3 = subplot(2,2,3);
axis([0,4,0,1]);
tau_p_marg = sum(slope_like,3,'omitnan');
imagesc('XData',[0 4],'YData',[0 1],'CData',tau_p_marg);
hold on
tau_p_sort = sort(tau_p_marg(:));
tau_p_cdf = 1-cumsum(tau_p_sort)/sum(tau_p_sort);
tau_p_val1 = min(tau_p_sort(tau_p_cdf <= .997));
tau_p_val2 = min(tau_p_sort(tau_p_cdf <= .95));
tau_p_val3 = min(tau_p_sort(tau_p_cdf <= .68));
contour(tt(:,:,1),pp(:,:,1),tau_p_marg,[tau_p_val1 tau_p_val2 tau_p_val3],...
    'color','r','linewidth',1,'linestyle','-')
c3 = colorbar;
xlabel({'End of Fan Formation','\tau_{end} (Ga)'});
ylabel({'Max Fan Formation Prob.','p_{max}'});
set(gca,'tickdir','out');

sub4 = subplot(2,2,4);
dur_p_marg = squeeze(sum(slope_like,2,'omitnan'));
imagesc('XData',[0 4],'YData',[0 1],'CData',dur_p_marg); 
hold on
dur_p_sort = sort(dur_p_marg(:));
dur_p_cdf = 1-cumsum(dur_p_sort)/sum(dur_p_sort);
dur_p_val1 = min(dur_p_sort(dur_p_cdf <= .997));
dur_p_val2 = min(dur_p_sort(dur_p_cdf <= .95));
dur_p_val3 = min(dur_p_sort(dur_p_cdf <= .68));
contour(squeeze(dd(:,1,:)),squeeze(pp(:,1,:)),dur_p_marg,[dur_p_val1 dur_p_val2 dur_p_val3],...
    'color','r','linewidth',1,'linestyle','-')

xlabel({'Fan Formation Era Duration','\Delta\tau (Gyr)'});
ylabel({'Max Fan Formation Prob.','p_{max}'});
set(gca,'tickdir','out');
axis([0 4 0 1]); 
c4 = colorbar;

sub5 = subplot(2,2,1);
tau_dur_marg = squeeze(sum(slope_like,1,'omitnan'))';
imagesc('XData',[0 4],'YData',[0 4],'CData',tau_dur_marg);
hold on
tau_dur_sort = sort(tau_dur_marg(:));
tau_dur_cdf = 1-cumsum(tau_dur_sort)/sum(tau_dur_sort);
tau_dur_val1 = min(tau_dur_sort(tau_dur_cdf <= .997));
tau_dur_val2 = min(tau_dur_sort(tau_dur_cdf <= .95));
tau_dur_val3 = min(tau_dur_sort(tau_dur_cdf <= .68));
contour(squeeze(dd(1,:,:)),squeeze(tt(1,:,:)),tau_dur_marg,[tau_dur_val1 tau_dur_val2 tau_dur_val3],...
    'color','r','linewidth',1,'linestyle','-')
v = [0 4; 4 4; 4 0];
f = [1 2 3];
patch('Faces',f,'Vertices',v,'FaceColor',[0.5 0.5 0.5])
ylabel({'Fan Formation Era Duration','\Delta\tau (Gyr)'});
xlabel({'End of Fan Formation','\tau_{end} (Ga)'});
set(gca,'tickdir','out');
axis([0 4 0 4]);
c5 = colorbar;

sub6 = subplot(2,2,2);
latest_prob = sum(slope_like,[1,3],'omitnan');
latest_prob = latest_prob/sum(latest_prob);
times = 0:0.1:4;
plot(times,latest_prob/dt3,'linewidth',2);
latest_cdf = cumsum(latest_prob);
cutoff = min(times(latest_cdf >= 0.95));
patch([cutoff times(times >= cutoff)],[0 latest_prob(times >= cutoff)]/dt3, [1 0 0],...
    'FaceAlpha',.3,'EdgeAlpha',0);
legend('PDF','p < 0.05');

grid minor
xlabel({'End of Fan Formation','\tau_{end} (Ga)'});
ylabel('Marginalized PDF');
set(gca,'tickdir','out');

fig4.PaperUnits = 'centimeters';
fig4.PaperPosition = [0 0 19.5 15];
print(fig4,'FIG4_spatial_2','-dtiffn','-r500');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fig5 = figure('color',[1 1 1]);
maximum = max(slope_like,[],'all');
[x,y,z] = find(slope_like == maximum);
set(gca,'fontsize',10);

sub7 = subplot(1,2,2);
axis([0,4,0,1]);
tau_dur_marg = squeeze(sum(slope_like,1,'omitnan'))';
imagesc('XData',[0 4],'YData',[0 4],'CData',tau_dur_marg);
hold on
tau_dur_sort = sort(tau_dur_marg(:));
tau_dur_cdf = 1-cumsum(tau_dur_sort)/sum(tau_dur_sort);
tau_dur_val1 = min(tau_dur_sort(tau_dur_cdf <= .997));
tau_dur_val2 = min(tau_dur_sort(tau_dur_cdf <= .95));
tau_dur_val3 = min(tau_dur_sort(tau_dur_cdf <= .68));
contour(squeeze(dd(1,:,:)),squeeze(tt(1,:,:)),tau_dur_marg,[tau_dur_val1 tau_dur_val2 tau_dur_val3],...
    'color','r','linewidth',1,'linestyle','-')
v = [0 4; 4 4; 4 0];
f = [1 2 3];
patch('Faces',f,'Vertices',v,'FaceColor',[0.5 0.5 0.5])
xticks([0 1 2 3 4]);
ylabel({'Fan Formation Era Duration','\Delta\tau (Gyr)'});
xlabel({'End of Fan Formation','\tau_{end} (Ga)'});
set(gca,'tickdir','out');
axis([0 4 0 4]);
c5 = colorbar;

sub8 = subplot(1,2,1);
set(gca,'fontsize',10);
imagesc('XData',[0 4],'YData',[0 1],'CData',step_like) %CHANGED FOR LF2
hold on
step_sorted = sort(step_like(:));
step_cdf = 1 - cumsum(step_sorted)/sum(step_sorted);
step_val1 = min(step_sorted(step_cdf <= .997));
step_val2 = min(step_sorted(step_cdf <= .95));
step_val3 = min(step_sorted(step_cdf <= .68));
contour(t_,p_,step_like,[step_val1 step_val2 step_val3],'color','r','linewidth',1,'linestyle','-')

axis([0 4 0 1]); 
c2 = colorbar;
xticks([0 1 2 3 4]);
xlabel({'Fan Formation Time','\tau_{form} (Ga)'});
ylabel({'Max Fan Formation Prob.','p_{max}'});
set(gca,'tickdir','out');
%plot([3 3],[0 1],'color','r','linewidth',1,'linestyle','--');
%plot([0 4],[0.5 0.5],'color','r','linewidth',1,'linestyle','--');

fig5.PaperUnits = 'centimeters';
fig5.PaperPosition = [0 0 19.5 7];
print(fig5,'FIG5_spatial_2','-dtiffn','-r500');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fig6 = figure('color',[1 1 1]);
sortedposts = [fan_posts2;non_fan_posts];
sortedlikes = [fan_likelihoods;non_fan_likelihoods];

sort_exp_ages = sortedposts*tc;
sortedcums = cumsum(sortedposts,2);

olderror = zeros(212,1);
youngerror = zeros(212,1);
michael_est = zeros(212,1);

for k = 1:212
    temp_posts = cumsum(sortedposts(k,:));
    temp_like = sortedlikes(k,:);
    
    upper_bound = min(tc(temp_posts' >= 0.95));
    lower_bound = max(tc(temp_posts' <= 0.05));
    
    olderror(k) = upper_bound - sort_exp_ages(k);
    youngerror(k) = sort_exp_ages(k) - lower_bound;
    michael_est(k) = min(tc(temp_like' >= 0.5));
end

% errorbar(1:212,sort_exp_ages, youngerror, olderror,'o');
numfans = sum(hasfans);
[sorted_fan_exp_ages, idx] = sort(sort_exp_ages(1:numfans));
fan_upper = olderror(1:numfans);
fan_lower = youngerror(1:numfans);
sorted_fan_upper = fan_upper(idx);
sorted_fan_lower = fan_lower(idx);

errorbar(1:numfans,sorted_fan_exp_ages,sorted_fan_lower,sorted_fan_upper,'o')
hold on

[sorted_nonfan_exp_ages, idx2] = sort(sort_exp_ages(numfans+1:end));
nonfan_upper = olderror(numfans+1:end);
nonfan_lower = youngerror(numfans+1:end);
sorted_nonfan_upper = nonfan_upper(idx2);
sorted_nonfan_lower = nonfan_lower(idx2);

fan_michael = michael_est(1:numfans);
nonfan_michael = michael_est(numfans+1:end);

sort_fan_michael = fan_michael(idx);
sort_nonfan_michael = nonfan_michael(idx2);

errorbar(numfans+1:212,sorted_nonfan_exp_ages,sorted_nonfan_lower,sorted_nonfan_upper,'o')
plot(1:212,[sort_fan_michael;sort_nonfan_michael],'o','color','k');
axis([0 212 0 4]);

%plot([0 212],[3.54 3.54],'--','color','k','linewidth',1);
%plot([0 212],[3.74 3.74],'-.','color','k','linewidth',1);
plot([0 212],[3.24 3.24],'--','color','k','linewidth',1); %Lines changed by Edwin Kite on 7/31/21
plot([0 212],[3.56 3.56],'-.','color','k','linewidth',1); %Lines changed by Edwin Kite on 7/31/21


legend({'Fan-Bearing','Non-Fan-Bearing','Michael et al. Estimates','A/H Boundary',...
    'N/H Boundary'},'location','southeast');

grid on
xlabel('AHi Sub-Unit Index');
ylabel('Age (Ga)');

fig6.PaperUnits = 'centimeters';
fig6.PaperPosition = [0 0 19.5 9.5];
print(fig6,'FIG6_spatial_2','-dtiffn','-r500');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [posterior, tc] = age_posterior(N,A,max_time)
    % Set some constants
    N1_ref = 5.84e-4;
    N4_ref = 4.25e-5;
    
    % Define the prior and posterior functions
    t = (0:0.01:max_time)';
    tc = 0.5*(t(1:end-1) + t(2:end));
    dens_t = (N4_ref/N1_ref)*(N1_ref*t + (3.79e-14)*(exp(6.93*t)-1));
    prior = diff(dens_t);
    likelihood = poisspdf(N,0.5*(dens_t(1:end-1) + dens_t(2:end))*A);
    
    % Define and renormalize the posterior
    posterior = prior.*likelihood;
    posterior = posterior./sum(posterior);    
end

function [prior, likelihood,tc] = age_prior(N,A,max_time)
    % Set some constants
    N1_ref = 5.84e-4;
    N4_ref = 4.25e-5;
    
    % Define the prior and posterior functions
    t = (0:0.01:max_time)';
    tc = 0.5*(t(1:end-1) + t(2:end));
    dens_t = (N4_ref/N1_ref)*(N1_ref*t + (3.79e-14)*(exp(6.93*t)-1));
    prior = diff(dens_t);
    likelihood = poisspdf(N,0.5*(dens_t(1:end-1) + dens_t(2:end))*A);
    
    % Define and renormalize the posterior
    posterior = prior.*likelihood;
    posterior = posterior./sum(posterior);    
end